Index: code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCenterPoint.cc
===================================================================
--- code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCenterPoint.cc	(revision 11837)
+++ code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCenterPoint.cc	(revision 11838)
@@ -28,31 +28,31 @@
 
 /**
-    @file DodgeRaceCenterPoint.cc
-    @brief Implementation of the DodgeRaceCenterPoint class.
+    @file OrxyRoadCenterPoint.cc
+    @brief Implementation of the OrxyRoadCenterPoint class.
 */
 
-#include "DodgeRaceCenterPoint.h"
+#include "OrxyRoadCenterPoint.h"
 
 #include "core/CoreIncludes.h"
 
-#include "DodgeRace.h"
+#include "OrxyRoad.h"
 
 namespace orxonox
 {
-    RegisterClass(DodgeRaceCenterPoint);
+    RegisterClass(OrxyRoadCenterPoint);
 
-    DodgeRaceCenterPoint::DodgeRaceCenterPoint(Context* context) : StaticEntity(context)
+    OrxyRoadCenterPoint::OrxyRoadCenterPoint(Context* context) : StaticEntity(context)
     {
-        RegisterObject(DodgeRaceCenterPoint);
+        RegisterObject(OrxyRoadCenterPoint);
 
         this->checkGametype();
     }
 
-    void DodgeRaceCenterPoint::checkGametype()
+    void OrxyRoadCenterPoint::checkGametype()
     {
-        if (this->getGametype() != nullptr && this->getGametype()->isA(Class(DodgeRace)))
+        if (this->getGametype() != nullptr && this->getGametype()->isA(Class(OrxyRoad)))
         {
-            DodgeRace* DodgeRaceGametype = orxonox_cast<DodgeRace*>(this->getGametype());
-            DodgeRaceGametype->setCenterpoint(this);
+            OrxyRoad* OrxyRoadGametype = orxonox_cast<OrxyRoad*>(this->getGametype());
+            OrxyRoadGametype->setCenterpoint(this);
         }
     }
Index: code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCenterPoint.h
===================================================================
--- code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCenterPoint.h	(revision 11837)
+++ code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCenterPoint.h	(revision 11838)
@@ -28,16 +28,16 @@
 
 /**
-    @file DodgeRaceCenterPoint.h
-    @brief Declaration of the DodgeRaceCenterPoint class.
-    @ingroup DodgeRace
+    @file OrxyRoadCenterPoint.h
+    @brief Declaration of the OrxyRoadCenterPoint class.
+    @ingroup OrxyRoad
 */
 
-#ifndef _DodgeRaceCenterPoint_H__
-#define _DodgeRaceCenterPoint_H__
+#ifndef _OrxyRoadCenterPoint_H__
+#define _OrxyRoadCenterPoint_H__
 
-#include "dodgerace/DodgeRacePrereqs.h"
+#include "OrxyRoad/OrxyRoadPrereqs.h"
 
-//#include "DodgeRace.h"
-//#include "DodgeRaceHUDinfo.h"
+//#include "OrxyRoad.h"
+//#include "OrxyRoadHUDinfo.h"
 
 #include "worldentities/StaticEntity.h"
@@ -45,8 +45,8 @@
 namespace orxonox
 {
-    class _DodgeRaceExport DodgeRaceCenterPoint : public StaticEntity
+    class _OrxyRoadExport OrxyRoadCenterPoint : public StaticEntity
     {
         public:
-            DodgeRaceCenterPoint(Context* context); //checks whether the gametype is actually DodgeRace.
+            OrxyRoadCenterPoint(Context* context); //checks whether the gametype is actually OrxyRoad.
 
         private:
@@ -56,3 +56,3 @@
 }
 
-#endif /* _DodgeRaceCenterPoint_H__ */
+#endif /* _OrxyRoadCenterPoint_H__ */
Index: code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCube.cc
===================================================================
--- code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCube.cc	(revision 11837)
+++ code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCube.cc	(revision 11838)
@@ -27,19 +27,19 @@
 
 /**
-    @file DodgeRace.cc
-    @brief Implementation of the DodgeRace class.
+    @file OrxyRoad.cc
+    @brief Implementation of the OrxyRoad class.
 */
 
-#include "DodgeRaceCube.h"
-#include "DodgeRace.h"
+#include "OrxyRoadCube.h"
+#include "OrxyRoad.h"
 #include "core/CoreIncludes.h"
 
 namespace orxonox
 {
-    RegisterClass(DodgeRaceCube);
+    RegisterClass(OrxyRoadCube);
 
-    DodgeRaceCube::DodgeRaceCube(Context* context) : MovableEntity(context)
+    OrxyRoadCube::OrxyRoadCube(Context* context) : MovableEntity(context)
     {
-        RegisterObject(DodgeRaceCube);
+        RegisterObject(OrxyRoadCube);
     }
 
Index: code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCube.h
===================================================================
--- code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCube.h	(revision 11837)
+++ code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadCube.h	(revision 11838)
@@ -28,13 +28,13 @@
 
 /**
-    @file DodgeRace.h
+    @file OrxyRoad.h
     @brief Gametype.
-    @ingroup DodgeRace
+    @ingroup OrxyRoad
 */
 
-#ifndef _DodgeRaceCube_H__
-#define _DodgeRaceCube_H__
+#ifndef _OrxyRoadCube_H__
+#define _OrxyRoadCube_H__
 
-#include "dodgerace/DodgeRacePrereqs.h"
+#include "OrxyRoad/OrxyRoadPrereqs.h"
 
 #include "worldentities/MovableEntity.h"
@@ -43,8 +43,8 @@
 namespace orxonox
 {
-    class _DodgeRaceExport DodgeRaceCube : public MovableEntity
+    class _OrxyRoadExport OrxyRoadCube : public MovableEntity
     {
        public:
-            DodgeRaceCube(Context* context);
+            OrxyRoadCube(Context* context);
 
        private:
@@ -52,3 +52,3 @@
 }
 
-#endif /* _DodgeRaceCube_H__ */
+#endif /* _OrxyRoadCube_H__ */
Index: code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadHUDinfo.cc
===================================================================
--- code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadHUDinfo.cc	(revision 11837)
+++ code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadHUDinfo.cc	(revision 11838)
@@ -25,39 +25,39 @@
  */
 
-#include "DodgeRaceHUDinfo.h"
+#include "OrxyRoadHUDinfo.h"
 
 #include "core/CoreIncludes.h"
 #include "core/XMLPort.h"
 #include "util/Convert.h"
-//#include "DodgeRace.h"
+//#include "OrxyRoad.h"
 
 namespace orxonox
 {
-    RegisterClass(DodgeRaceHUDinfo);
+    RegisterClass(OrxyRoadHUDinfo);
 
-    DodgeRaceHUDinfo::DodgeRaceHUDinfo(Context* context) : OverlayText(context)
+    OrxyRoadHUDinfo::OrxyRoadHUDinfo(Context* context) : OverlayText(context)
     {
-        RegisterObject(DodgeRaceHUDinfo);
+        RegisterObject(OrxyRoadHUDinfo);
 
-        this->DodgeRaceGame = nullptr;
+        this->OrxyRoadGame = nullptr;
         this->bShowPoints_ = true;
     }
 
-    void DodgeRaceHUDinfo::XMLPort(Element& xmlelement, XMLPort::Mode mode)
+    void OrxyRoadHUDinfo::XMLPort(Element& xmlelement, XMLPort::Mode mode)
     {
-        SUPER(DodgeRaceHUDinfo, XMLPort, xmlelement, mode);
+        SUPER(OrxyRoadHUDinfo, XMLPort, xmlelement, mode);
 
-        XMLPortParam(DodgeRaceHUDinfo,"showPoints", setShowPoints, getShowPoints, xmlelement, mode).defaultValues(false);
+        XMLPortParam(OrxyRoadHUDinfo,"showPoints", setShowPoints, getShowPoints, xmlelement, mode).defaultValues(false);
     }
 
-    void DodgeRaceHUDinfo::tick(float dt)
+    void OrxyRoadHUDinfo::tick(float dt)
     {
-        SUPER(DodgeRaceHUDinfo, tick, dt);
+        SUPER(OrxyRoadHUDinfo, tick, dt);
 
 
         if(this->bShowPoints_)
         {
-            const std::string& points = multi_cast<std::string>(this->DodgeRaceGame->getPoints());
-            if (this->DodgeRaceGame->lives <= 0)
+            const std::string& points = multi_cast<std::string>(this->OrxyRoadGame->getPoints());
+            if (this->OrxyRoadGame->lives <= 0)
             {
                 setTextSize(0.2);
@@ -76,15 +76,15 @@
     }
 
-    void DodgeRaceHUDinfo::changedOwner()
+    void OrxyRoadHUDinfo::changedOwner()
     {
-        SUPER(DodgeRaceHUDinfo, changedOwner);
+        SUPER(OrxyRoadHUDinfo, changedOwner);
 
         if (this->getOwner() && this->getOwner()->getGametype())
         {
-            this->DodgeRaceGame = orxonox_cast<DodgeRace*>(this->getOwner()->getGametype());
+            this->OrxyRoadGame = orxonox_cast<OrxyRoad*>(this->getOwner()->getGametype());
         }
         else
         {
-            this->DodgeRaceGame = nullptr;
+            this->OrxyRoadGame = nullptr;
         }
     }
Index: code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadHUDinfo.h
===================================================================
--- code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadHUDinfo.h	(revision 11837)
+++ code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadHUDinfo.h	(revision 11838)
@@ -25,12 +25,12 @@
  */
 
-#ifndef _DodgeRaceHUDinfo_H__
-#define _DodgeRaceHUDinfo_H__
+#ifndef _OrxyRoadHUDinfo_H__
+#define _OrxyRoadHUDinfo_H__
 
-//#include "DodgeRaceShip.h"
-#include "DodgeRace.h"
-//#include "DodgeRaceCenterPoint.h"
+//#include "OrxyRoadShip.h"
+#include "OrxyRoad.h"
+//#include "OrxyRoadCenterPoint.h"
 
-#include "dodgerace/DodgeRacePrereqs.h"
+#include "OrxyRoad/OrxyRoadPrereqs.h"
 
 #include "tools/interfaces/Tickable.h"
@@ -39,8 +39,8 @@
 namespace orxonox
 {
-    class _DodgeRaceExport DodgeRaceHUDinfo : public OverlayText, public Tickable
+    class _OrxyRoadExport OrxyRoadHUDinfo : public OverlayText, public Tickable
     {
      public:
-            DodgeRaceHUDinfo(Context* context);
+            OrxyRoadHUDinfo(Context* context);
 
             virtual void tick(float dt) override;
@@ -55,7 +55,7 @@
 
         private:
-            DodgeRace* DodgeRaceGame;
+            OrxyRoad* OrxyRoadGame;
             bool bShowPoints_;
     };
 }
-#endif /* _DodgeRaceHUDinfo_H__ */
+#endif /* _OrxyRoadHUDinfo_H__ */
Index: code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadPrereqs.h
===================================================================
--- code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadPrereqs.h	(revision 11837)
+++ code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadPrereqs.h	(revision 11838)
@@ -30,9 +30,9 @@
 @file
 @brief
-    Shared library macros, enums, constants and forward declarations for the DodgeRace module
+    Shared library macros, enums, constants and forward declarations for the OrxyRoad module
 */
 
-#ifndef _DodgeRacePrereqs_H__
-#define _DodgeRacePrereqs_H__
+#ifndef _OrxyRoadPrereqs_H__
+#define _OrxyRoadPrereqs_H__
 
 #include "OrxonoxConfig.h"
@@ -43,21 +43,21 @@
 //-----------------------------------------------------------------------
 
-#if defined(ORXONOX_PLATFORM_WINDOWS) && !defined(DODGERACE_STATIC_BUILD)
-#  ifdef DODGERACE_SHARED_BUILD
-#    define _DodgeRaceExport __declspec(dllexport)
+#if defined(ORXONOX_PLATFORM_WINDOWS) && !defined(OrxyRoad_STATIC_BUILD)
+#  ifdef OrxyRoad_SHARED_BUILD
+#    define _OrxyRoadExport __declspec(dllexport)
 #  else
 #    if defined( __MINGW32__ )
-#      define _DodgeRaceExport
+#      define _OrxyRoadExport
 #    else
-#      define _DodgeRaceExport __declspec(dllimport)
+#      define _OrxyRoadExport __declspec(dllimport)
 #    endif
 #  endif
-#  define _DodgeRacePrivate
+#  define _OrxyRoadPrivate
 #elif defined (ORXONOX_GCC_VISIBILITY)
-#  define _DodgeRaceExport  __attribute__ ((visibility("default")))
-#  define _DodgeRacePrivate __attribute__ ((visibility("hidden")))
+#  define _OrxyRoadExport  __attribute__ ((visibility("default")))
+#  define _OrxyRoadPrivate __attribute__ ((visibility("hidden")))
 #else
-#  define _DodgeRaceExport
-#  define _DodgeRacePrivate
+#  define _OrxyRoadExport
+#  define _OrxyRoadPrivate
 #endif
 
@@ -68,14 +68,14 @@
 namespace orxonox
 {
-    class DodgeRace;
-    class DodgeRaceCenterPoint;
-    class DodgeRaceShip;
-    class DodgeRaceCube;
-    //class DodgeRaceEnemy;
-    //class DodgeRaceEnemyShooter;
-    //class DodgeRaceWeapon;
-    //class DodgeRaceWeaponEnemy;
-    //class DodgeRaceHUDinfo;
+    class OrxyRoad;
+    class OrxyRoadCenterPoint;
+    class OrxyRoadShip;
+    class OrxyRoadCube;
+    //class OrxyRoadEnemy;
+    //class OrxyRoadEnemyShooter;
+    //class OrxyRoadWeapon;
+    //class OrxyRoadWeaponEnemy;
+    //class OrxyRoadHUDinfo;
 }
 
-#endif /* _DodgeRacePrereqs_H__*/
+#endif /* _OrxyRoadPrereqs_H__*/
Index: code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadRaceShip.cc
===================================================================
--- code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadRaceShip.cc	(revision 11837)
+++ code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadRaceShip.cc	(revision 11838)
@@ -28,18 +28,18 @@
 
 /**
-    @file DodgeRaceShip.cc
-    @brief Implementation of the DodgeRaceShip class.
+    @file OrxyRoadShip.cc
+    @brief Implementation of the OrxyRoadShip class.
 */
 
-#include "DodgeRaceShip.h"
+#include "OrxyRoadShip.h"
 #include "core/CoreIncludes.h"
 
 namespace orxonox
 {
-    RegisterClass(DodgeRaceShip);
+    RegisterClass(OrxyRoadShip);
 
-    DodgeRaceShip::DodgeRaceShip(Context* context) : SpaceShip(context)
+    OrxyRoadShip::OrxyRoadShip(Context* context) : SpaceShip(context)
     {
-        RegisterObject(DodgeRaceShip);
+        RegisterObject(OrxyRoadShip);
 
         speed = 830;
@@ -53,5 +53,5 @@
     }
 
-    void DodgeRaceShip::tick(float dt)
+    void OrxyRoadShip::tick(float dt)
     {
         Vector3 pos = getPosition();
@@ -115,8 +115,8 @@
         }
 
-        SUPER(DodgeRaceShip, tick, dt);
+        SUPER(OrxyRoadShip, tick, dt);
     }
 
-    void DodgeRaceShip::updateLevel()
+    void OrxyRoadShip::updateLevel()
     {
         lastTime = 0;
@@ -125,5 +125,5 @@
     }
 
-    void DodgeRaceShip::moveFrontBack(const Vector2& value)
+    void OrxyRoadShip::moveFrontBack(const Vector2& value)
     {
         //lastTimeFront = 0;
@@ -132,15 +132,15 @@
     }
 
-    void DodgeRaceShip::moveRightLeft(const Vector2& value)
+    void OrxyRoadShip::moveRightLeft(const Vector2& value)
     {
         lastTimeLeft = 0;
         desiredVelocity.x = value.x * speed;
     }
-    void DodgeRaceShip::boost(bool bBoost)
+    void OrxyRoadShip::boost(bool bBoost)
     {
         //getGame()->bEndGame = bBoost;
     }
 
-    inline bool DodgeRaceShip::collidesAgainst(WorldEntity* otherObject, const btCollisionShape* ownCollisionShape, btManifoldPoint& contactPoint)
+    inline bool OrxyRoadShip::collidesAgainst(WorldEntity* otherObject, const btCollisionShape* ownCollisionShape, btManifoldPoint& contactPoint)
     {
 
@@ -150,9 +150,9 @@
     }
 
-    DodgeRace* DodgeRaceShip::getGame()
+    OrxyRoad* OrxyRoadShip::getGame()
     {
         if (game == nullptr)
         {
-            for (DodgeRace* race : ObjectList<DodgeRace>())
+            for (OrxyRoad* race : ObjectList<OrxyRoad>())
             {
                 game = race;
@@ -162,5 +162,5 @@
     }
 
-    void DodgeRaceShip::death()
+    void OrxyRoadShip::death()
     {
         getGame()->costLife();
Index: code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadRaceShip.h
===================================================================
--- code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadRaceShip.h	(revision 11837)
+++ code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadRaceShip.h	(revision 11838)
@@ -28,13 +28,13 @@
 
 /**
-    @file DodgeRaceShip.h
-    @brief Declaration of the DodgeRaceShip class.
+    @file OrxyRoadShip.h
+    @brief Declaration of the OrxyRoadShip class.
 */
 
-#ifndef _DodgeRaceShip_H__
-#define _DodgeRaceShip_H__
+#ifndef _OrxyRoadShip_H__
+#define _OrxyRoadShip_H__
 
 
-#include "dodgerace/DodgeRacePrereqs.h"
+#include "OrxyRoad/OrxyRoadPrereqs.h"
 
 #include "core/XMLPort.h"
@@ -42,13 +42,13 @@
 #include "graphics/Camera.h"
 
-#include "DodgeRace.h" // Is necessary for getGame function
-//#include "DodgeRaceCenterPoint.h"
+#include "OrxyRoad.h" // Is necessary for getGame function
+//#include "OrxyRoadCenterPoint.h"
 
 namespace orxonox
 {
-    class _DodgeRaceExport DodgeRaceShip : public SpaceShip
+    class _OrxyRoadExport OrxyRoadShip : public SpaceShip
     {
         public:
-            DodgeRaceShip(Context* context);
+            OrxyRoadShip(Context* context);
 
             virtual void tick(float dt) override;
@@ -79,6 +79,6 @@
 
         private:
-            DodgeRace* getGame();
-            WeakPtr<DodgeRace> game;
+            OrxyRoad* getGame();
+            WeakPtr<OrxyRoad> game;
             WeakPtr<WorldEntity> lastEntity;
             Camera* camera;
@@ -93,3 +93,3 @@
 }
 
-#endif /* _DodgeRaceShip_H__ */
+#endif /* _OrxyRoadShip_H__ */

Index: code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadRace.h
===================================================================
--- code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadRace.h	(revision 11837)
+++ code/branches/OrxyRoad_FS18/src/modules/orxyroad/OrxyRoadRace.h	(revision 11838)
@@ -28,18 +28,18 @@
 
 /**
-    @file DodgeRace.h
+    @file OrxyRoad.h
     @brief Gametype.
-    @ingroup DodgeRace
+    @ingroup OrxyRoad
 */
 
-#ifndef _DodgeRace_H__
-#define _DodgeRace_H__
+#ifndef _OrxyRoad_H__
+#define _OrxyRoad_H__
 
-#include "dodgerace/DodgeRacePrereqs.h"
+#include "OrxyRoad/OrxyRoadPrereqs.h"
 
 #include "DodgeRaceCenterPoint.h" // Necessary for WeakPointer??
 //#include "DodgeRaceShip.h"        DO NOT include in Header. Will cause forward declaration issues
 
-//#include "DodgeRaceHUDinfo.h"
+//#include "OrxyRoadHUDinfo.h"
 
 
@@ -63,8 +63,8 @@
 {
 
-    class _DodgeRaceExport DodgeRace : public Deathmatch
+    class _OrxyRoadExport OrxyRoad : public Deathmatch
     {
        public:
-            DodgeRace(Context* context);
+            OrxyRoad(Context* context);
 
             virtual void start() override;
@@ -82,5 +82,5 @@
             int getMultiplier(){return this->multiplier;}
 
-            void setCenterpoint(DodgeRaceCenterPoint* center)
+            void setCenterpoint(OrxyRoadCenterPoint* center)
                        { this->center_ = center; }
             virtual void addBots(unsigned int amount) override{} //<! overwrite function in order to bypass the addbots command
@@ -102,11 +102,11 @@
             Timer endGameTimer;
 
-            DodgeRaceShip* getPlayer();
+            OrxyRoadShip* getPlayer();
             WeakPtr<PlayerInfo> playerInfo_;
-            std::vector<DodgeRaceCube*> cubeList;
+            std::vector<OrxyRoadCube*> cubeList;
             void toggleShowLevel(){bShowLevel = !bShowLevel;}
             void addPoints(int numPoints);
 
-            WeakPtr<DodgeRaceCenterPoint> center_;
+            WeakPtr<OrxyRoadCenterPoint> center_;
             int level;
             int point;
@@ -143,3 +143,3 @@
 }
 
-#endif /* _DodgeRace_H__ */
+#endif /* _OrxyRoad_H__ */
@@ -28,18 +28,18 @@
 
-#include "DodgeRaceCenterPoint.h" // Necessary for WeakPointer??
-//#include "DodgeRaceShip.h"        DO NOT include in Header. Will cause forward declaration issues
+#include "OrxyRoadCenterPoint.h" // Necessary for WeakPointer??
+//#include "OrxyRoadShip.h"        DO NOT include in Header. Will cause forward declaration issues
 